@@ -23,6 +23,11 @@ public:
     const PIRKeysetManager *keyset,
     unsigned int id);
 
+  void enableButtons(
+    const PIRKeysetManager *keyset,
+    unsigned int currentID,
+    unsigned int defaultID);
+
 signals:
   void powerEnabled(bool);
   void volumeUpEnabled(bool);
@@ -52,6 +57,7 @@ private:
   Ui::PIRMainForm *ui;
 
   MainWindow *mainWindow;
+  unsigned int defaultID;
 };
 
 #endif // PIRMAINFORM_H
