@@ -36,6 +36,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Dish_Make] = "Dish";
   makes[Dreambox_Make] = "Dream Multimedia";
   makes[DSE_Make] = "DSE (Dick Smith)";
+  makes[Dune_Make] = "Dune";
   makes[Dynex_Make] = "Dynex";
   makes[Ei_Make] = "Ei";
   makes[Elgato_Make] = "Elgato";
@@ -80,6 +81,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Microsoft_Make] = "Microsoft";
   makes[Mitsubishi_Make] = "Mitsubishi";
   makes[Motorola_Make] = "Motorola";
+  makes[MTLogic_Make] = "MT-Logic";
   makes[Multichoice_Make] = "Multichoice";
   makes[NAD_Make] = "NAD";
   makes[NEC_Make] = "NEC";
@@ -125,6 +127,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Triax_Make] = "Triax";
   makes[United_Make] = "United";
   makes[Universum_Make] = "Universum";
+  makes[Venturer_Make] = "Venturer";
   makes[Vestel_Make] = "Vestel";
   makes[Viewsat_Make] = "Viewsat";
   makes[Viewsonic_Make] = "Viewsonic";
