@@ -37,6 +37,7 @@ enum PIRMakeName{
   Dish_Make,
   Dreambox_Make,
   DSE_Make,
+  Dune_Make,
   Dynex_Make,
   Ei_Make,
   Elgato_Make,
@@ -81,6 +82,7 @@ enum PIRMakeName{
   Microsoft_Make,
   Mitsubishi_Make,
   Motorola_Make,
+  MTLogic_Make,
   Multichoice_Make,
   NAD_Make,
   NEC_Make,
@@ -126,6 +128,7 @@ enum PIRMakeName{
   Triax_Make,
   United_Make,
   Universum_Make,
+  Venturer_Make,
   Vestel_Make,
   Viewsat_Make,
   Viewsonic_Make,
